-- MIMIC III 
-- SQL Server Create Table Scripts
--
-- https://mimic.physionet.org/


use MIMIC3;
GO


DROP TABLE IF EXISTS ADMISSIONS;
CREATE TABLE ADMISSIONS (	-- rows=58976
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   ADMITTIME DATETIME NOT NULL,
   DISCHTIME DATETIME NOT NULL,
   DEATHTIME DATETIME,
   ADMISSION_TYPE VARCHAR(50) NOT NULL,	-- max=9
   ADMISSION_LOCATION VARCHAR(50) NOT NULL,	-- max=25
   DISCHARGE_LOCATION VARCHAR(50) NOT NULL,	-- max=25
   INSURANCE VARCHAR(255) NOT NULL,	-- max=10
   LANGUAGE VARCHAR(10),	-- max=4
   RELIGION VARCHAR(50),	-- max=22
   MARITAL_STATUS VARCHAR(50),	-- max=17
   ETHNICITY VARCHAR(200) NOT NULL,	-- max=56
   EDREGTIME DATETIME,
   EDOUTTIME DATETIME,
   DIAGNOSIS  VARCHAR(300),	-- max=189
   HOSPITAL_EXPIRE_FLAG TINYINT  NOT NULL,
   HAS_CHARTEVENTS_DATA TINYINT  NOT NULL,
   CONSTRAINT PK_ADMISSIONS PRIMARY KEY CLUSTERED (HADM_ID)
  )
;










DROP TABLE IF EXISTS CALLOUT;
CREATE TABLE CALLOUT (	-- rows=34499
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   SUBMIT_WARDID TINYINT ,
   SUBMIT_CAREUNIT VARCHAR(15),	-- max=5
   CURR_WARDID TINYINT ,
   CURR_CAREUNIT VARCHAR(15),	-- max=5
   CALLOUT_WARDID TINYINT  NOT NULL,
   CALLOUT_SERVICE VARCHAR(255) NOT NULL,	-- max=5
   REQUEST_TELE TINYINT  NOT NULL,
   REQUEST_RESP TINYINT  NOT NULL,
   REQUEST_CDIFF TINYINT  NOT NULL,
   REQUEST_MRSA TINYINT  NOT NULL,
   REQUEST_VRE TINYINT  NOT NULL,
   CALLOUT_STATUS VARCHAR(255) NOT NULL,	-- max=8
   CALLOUT_OUTCOME VARCHAR(255) NOT NULL,	-- max=10
   DISCHARGE_WARDID TINYINT ,
   ACKNOWLEDGE_STATUS VARCHAR(255) NOT NULL,	-- max=14
   CREATETIME DATETIME NOT NULL,
   UPDATETIME DATETIME NOT NULL,
   ACKNOWLEDGETIME DATETIME,
   OUTCOMETIME DATETIME NOT NULL,
   FIRSTRESERVATIONTIME DATETIME,
   CURRENTRESERVATIONTIME DATETIME,
   CONSTRAINT PK_CALLOUT PRIMARY KEY CLUSTERED (ROW_ID) -- nvals=34499
  )
  ;


DROP TABLE IF EXISTS CAREGIVERS;
CREATE TABLE CAREGIVERS (	-- rows=7567
   ROW_ID INT  NOT NULL,
   CGID SMALLINT  NOT NULL,
   LABEL VARCHAR(255),	-- max=6
   DESCRIPTION VARCHAR(255),	-- max=21
   CONSTRAINT PK_CAREGIVERS PRIMARY KEY CLUSTERED (CGID)
  )
;







DROP TABLE IF EXISTS CHARTEVENTS;
CREATE TABLE CHARTEVENTS (	-- rows=263201375
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT ,
   ICUSTAY_ID INT ,
   ITEMID INT  NOT NULL,
   CHARTTIME DATETIME NOT NULL,
   STORETIME DATETIME,
   CGID SMALLINT ,
   VALUE VARCHAR(200),	-- max=91
   VALUENUM FLOAT,
   VALUEUOM VARCHAR(20),	-- max=17
   WARNING TINYINT ,
   ERROR TINYINT ,
   RESULTSTATUS VARCHAR(20),	-- max=6
   STOPPED VARCHAR(20),	-- max=8
--  CONSTRAINT CHARTEVENTS_ROW_ID UNIQUE(ROW_ID)	-- nvals=263201375
  )
;



-- Since CHARTEVENTS is such a huge table, A clustered index is created so the data is stored 
-- in an order that makes querying as fast as possible

CREATE UNIQUE CLUSTERED INDEX [IDX_CHARTEVENTS_CLUSTERED] ON [dbo].[CHARTEVENTS]
(
	[SUBJECT_ID] ASC,
	[ITEMID] ASC,
	[CHARTTIME] ASC,
	[ROW_ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
;











DROP TABLE IF EXISTS CPTEVENTS;
CREATE TABLE CPTEVENTS (	-- rows=573146
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   COSTCENTER VARCHAR(10) NOT NULL,	-- max=4
   CHARTDATE DATETIME,
   CPT_CD VARCHAR(10) NOT NULL,	-- max=5
   CPT_NUMBER INT ,
   CPT_SUFFIX VARCHAR(5),	-- max=1
   TICKET_ID_SEQ SMALLINT ,
   SECTIONHEADER VARCHAR(50),	-- max=25
   SUBSECTIONHEADER VARCHAR(300),	-- max=169
   DESCRIPTION VARCHAR(255),	-- max=30
   CONSTRAINT PK_CPTEVENTS PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=573146
  )
;



DROP TABLE IF EXISTS DATETIMEEVENTS;
CREATE TABLE DATETIMEEVENTS (	-- rows=4486049
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT ,
   ICUSTAY_ID INT ,
   ITEMID INT  NOT NULL,
   CHARTTIME DATETIME NOT NULL,
   STORETIME DATETIME NOT NULL,
   CGID SMALLINT  NOT NULL,
   VALUE DATETIME,
   VALUEUOM VARCHAR(255) NOT NULL,	-- max=13
   WARNING TINYINT ,
   ERROR TINYINT ,
   RESULTSTATUS VARCHAR(255),	-- max=0
   STOPPED VARCHAR(255),	-- max=8
   CONSTRAINT PK_DATETIMEEVENTS PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=4486049
  )
;




DROP TABLE IF EXISTS DIAGNOSES_ICD;
CREATE TABLE DIAGNOSES_ICD (	-- rows=651047
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   SEQ_NUM TINYINT ,
   ICD9_CODE VARCHAR(255),	-- max=5
   CONSTRAINT PK_DIAGNOSES_ICD PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=651047
  )
;




DROP TABLE IF EXISTS DRGCODES;
CREATE TABLE DRGCODES (	-- rows=125557
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   DRG_TYPE VARCHAR(20) NOT NULL,	-- max=4
   DRG_CODE VARCHAR(20) NOT NULL,	-- max=4
   DESCRIPTION VARCHAR(300),	-- max=193
   DRG_SEVERITY TINYINT ,
   DRG_MORTALITY TINYINT ,
   CONSTRAINT PK_DRGCODES PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=125557
  )
;




DROP TABLE IF EXISTS D_CPT;
CREATE TABLE D_CPT (	-- rows=134
   ROW_ID INT  NOT NULL,
   CATEGORY TINYINT  NOT NULL,
   SECTIONRANGE VARCHAR(100) NOT NULL,	-- max=37
   SECTIONHEADER VARCHAR(50) NOT NULL,	-- max=25
   SUBSECTIONRANGE VARCHAR(100) NOT NULL,	-- max=11
   SUBSECTIONHEADER VARCHAR(300) NOT NULL,	-- max=169
   CODESUFFIX VARCHAR(5),	-- max=1
   MINCODEINSUBSECTION INT  NOT NULL,
   MAXCODEINSUBSECTION INT  NOT NULL,
   CONSTRAINT PK_D_CPT PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=134
--  CONSTRAINT D_CPT_SUBSECTIONRANGE UNIQUE(SUBSECTIONRANGE),	-- nvals=134
--  CONSTRAINT D_CPT_MAXCODEINSUBSECTION UNIQUE(MAXCODEINSUBSECTION)	-- nvals=134
  )
;




DROP TABLE IF EXISTS D_ICD_DIAGNOSES;
CREATE TABLE D_ICD_DIAGNOSES (	-- rows=14567
   ROW_ID INT  NOT NULL,
   ICD9_CODE VARCHAR(10) NOT NULL,	-- max=5
   SHORT_TITLE VARCHAR(50) NOT NULL,	-- max=24
   LONG_TITLE VARCHAR(300) NOT NULL,	-- max=222
   CONSTRAINT PK_D_ICD_DIAGNOSES PRIMARY KEY CLUSTERED (ICD9_CODE)-- nvals=14567
  )
;




DROP TABLE IF EXISTS D_ICD_PROCEDURES;
CREATE TABLE D_ICD_PROCEDURES (	-- rows=3882
   ROW_ID INT  NOT NULL,
   ICD9_CODE VARCHAR(10) NOT NULL,	-- max=4
   SHORT_TITLE VARCHAR(50) NOT NULL,	-- max=24
   LONG_TITLE VARCHAR(300) NOT NULL,	-- max=163
   CONSTRAINT PK_D_ICD_PROCEDURES PRIMARY KEY CLUSTERED (ICD9_CODE)
  )
;




DROP TABLE IF EXISTS D_ITEMS;
CREATE TABLE D_ITEMS (	-- rows=12478
   ROW_ID INT  NOT NULL,
   ITEMID INT  NOT NULL,
   LABEL VARCHAR(255),	-- max=95
   ABBREVIATION VARCHAR(255),	-- max=50
   DBSOURCE VARCHAR(255) NOT NULL,	-- max=10
   LINKSTO VARCHAR(255),	-- max=18
   CATEGORY VARCHAR(255),	-- max=27
   UNITNAME VARCHAR(255),	-- max=19
   PARAM_TYPE VARCHAR(255),	-- max=16
   CONCEPTID VARCHAR(255),	-- max=0
   CONSTRAINT PK_D_ITEMS PRIMARY KEY CLUSTERED (ITEMID)-- nvals=12478
  )
;




DROP TABLE IF EXISTS D_LABITEMS;
CREATE TABLE D_LABITEMS (	-- rows=755
   ROW_ID INT  NOT NULL,
   ITEMID INT  NOT NULL,
   LABEL VARCHAR(255) NOT NULL,	-- max=36
   FLUID VARCHAR(255) NOT NULL,	-- max=25
   CATEGORY VARCHAR(255) NOT NULL,	-- max=10
   LOINC_CODE VARCHAR(255),	-- max=7
   CONSTRAINT PK_D_LABITEMS PRIMARY KEY CLUSTERED (ITEMID)-- nvals=755
  )
;




DROP TABLE IF EXISTS ICUSTAYS;
CREATE TABLE ICUSTAYS (	-- rows=61532
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   ICUSTAY_ID INT  NOT NULL,
   DBSOURCE VARCHAR(255) NOT NULL,	-- max=10
   FIRST_CAREUNIT VARCHAR(255) NOT NULL,	-- max=5
   LAST_CAREUNIT VARCHAR(255) NOT NULL,	-- max=5
   FIRST_WARDID TINYINT  NOT NULL,
   LAST_WARDID TINYINT  NOT NULL,
   INTIME DATETIME NOT NULL,
   OUTTIME DATETIME,
   LOS FLOAT,
   CONSTRAINT PK_ICUSTAYS PRIMARY KEY CLUSTERED (ICUSTAY_ID)-- nvals=61532
  )
;




DROP TABLE IF EXISTS INPUTEVENTS_CV;
CREATE TABLE INPUTEVENTS_CV (	-- rows=17528894
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT ,
   ICUSTAY_ID INT ,
   CHARTTIME DATETIME NOT NULL,
   ITEMID INT  NOT NULL,
   AMOUNT FLOAT,
   AMOUNTUOM VARCHAR(255),	-- max=3
   RATE FLOAT,
   RATEUOM VARCHAR(255),	-- max=8
   STORETIME DATETIME NOT NULL,
   CGID SMALLINT ,
   ORDERID INT  NOT NULL,
   LINKORDERID INT  NOT NULL,
   STOPPED VARCHAR(255),	-- max=8
   NEWBOTTLE TINYINT ,
   ORIGINALAMOUNT FLOAT,
   ORIGINALAMOUNTUOM VARCHAR(255),	-- max=3
   ORIGINALROUTE VARCHAR(255),	-- max=20
   ORIGINALRATE FLOAT,
   ORIGINALRATEUOM VARCHAR(255),	-- max=5
   ORIGINALSITE VARCHAR(255),	-- max=20
   CONSTRAINT PK_INPUTEVENTS_CV PRIMARY KEY CLUSTERED (ROW_ID) -- nvals=17528894
  )
;




DROP TABLE IF EXISTS INPUTEVENTS_MV;
CREATE TABLE INPUTEVENTS_MV (	-- rows=3618991
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   ICUSTAY_ID INT ,
   STARTTIME DATETIME NOT NULL,
   ENDTIME DATETIME NOT NULL,
   ITEMID INT  NOT NULL,
   AMOUNT FLOAT NOT NULL,
   AMOUNTUOM VARCHAR(255) NOT NULL,	-- max=19
   RATE FLOAT,
   RATEUOM VARCHAR(255),	-- max=12
   STORETIME DATETIME NOT NULL,
   CGID SMALLINT  NOT NULL,
   ORDERID INT  NOT NULL,
   LINKORDERID INT  NOT NULL,
   ORDERCATEGORYNAME VARCHAR(255) NOT NULL,	-- max=24
   SECONDARYORDERCATEGORYNAME VARCHAR(255),	-- max=24
   ORDERCOMPONENTTYPEDESCRIPTION VARCHAR(255) NOT NULL,	-- max=57
   ORDERCATEGORYDESCRIPTION VARCHAR(255) NOT NULL,	-- max=14
   PATIENTWEIGHT FLOAT NOT NULL,
   TOTALAMOUNT FLOAT,
   TOTALAMOUNTUOM VARCHAR(255),	-- max=2
   ISOPENBAG TINYINT  NOT NULL,
   CONTINUEINNEXTDEPT TINYINT  NOT NULL,
   CANCELREASON TINYINT  NOT NULL,
   STATUSDESCRIPTION VARCHAR(255) NOT NULL,	-- max=15
   COMMENTS_EDITEDBY VARCHAR(255),	-- max=15
   COMMENTS_CANCELEDBY VARCHAR(255),	-- max=15
   COMMENTS_DATE DATETIME,
   ORIGINALAMOUNT FLOAT NOT NULL,
   ORIGINALRATE FLOAT NOT NULL,
   CONSTRAINT PK_INPUTEVENTS_MV PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=3618991
  )
;




DROP TABLE IF EXISTS LABEVENTS;
CREATE TABLE LABEVENTS (	-- rows=27872575
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT ,
   ITEMID INT  NOT NULL,
   CHARTTIME DATETIME NOT NULL,
   VALUE VARCHAR(255),	-- max=100
   VALUENUM FLOAT,
   VALUEUOM VARCHAR(255),	-- max=10
   FLAG VARCHAR(255),	-- max=8
   CONSTRAINT PK_LABEVENTS PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=27872575
  )
;




DROP TABLE IF EXISTS MICROBIOLOGYEVENTS;
CREATE TABLE MICROBIOLOGYEVENTS (	-- rows=328446
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT ,
   CHARTDATE DATETIME NOT NULL,
   CHARTTIME DATETIME,
   SPEC_ITEMID INT ,
   SPEC_TYPE_DESC VARCHAR(255) NOT NULL,	-- max=56
   ORG_ITEMID INT ,
   ORG_NAME VARCHAR(255),	-- max=70
   ISOLATE_NUM TINYINT ,
   AB_ITEMID INT ,
   AB_NAME VARCHAR(255),	-- max=20
   DILUTION_TEXT VARCHAR(255),	-- max=6
   DILUTION_COMPARISON VARCHAR(255),	-- max=2
   DILUTION_VALUE SMALLINT ,
   INTERPRETATION VARCHAR(255),	-- max=1
   CONSTRAINT PK_MICROBIOLOGYEVENTS PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=328446
  )
;




DROP TABLE IF EXISTS NOTEEVENTS;
CREATE TABLE NOTEEVENTS (	-- rows=2078705
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT ,
   CHARTDATE DATE NOT NULL,
   CHARTTIME DATETIME,
   STORETIME DATETIME,
   CATEGORY VARCHAR(255) NOT NULL,	-- max=17
   DESCRIPTION VARCHAR(255) NOT NULL,	-- max=80
   CGID SMALLINT ,
   ISERROR TINYINT ,
   TEXT nvarchar(max),	-- max=55725
   CONSTRAINT PK_NOTEEVENTS PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=2078705
  )
;




DROP TABLE IF EXISTS OUTPUTEVENTS;
CREATE TABLE OUTPUTEVENTS (	-- rows=4349339
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT ,
   ICUSTAY_ID INT ,
   CHARTTIME DATETIME NOT NULL,
   ITEMID INT  NOT NULL,
   VALUE FLOAT,
   VALUEUOM VARCHAR(255),	-- max=2
   STORETIME DATETIME NOT NULL,
   CGID SMALLINT  NOT NULL,
   STOPPED VARCHAR(255),	-- max=0
   NEWBOTTLE VARCHAR(255),	-- max=0
   ISERROR VARCHAR(255),	-- max=0
   CONSTRAINT PK_OUTPUTEVENTS PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=4349339

  )
;




DROP TABLE IF EXISTS PATIENTS;
CREATE TABLE PATIENTS (	-- rows=46520
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   GENDER VARCHAR(255) NOT NULL,	-- max=1
   DOB DATETIME,	-- max=19
   DOD DATETIME,
   DOD_HOSP DATETIME,
   DOD_SSN DATETIME,
   EXPIRE_FLAG TINYINT  NOT NULL,
   CONSTRAINT PK_PATIENTS PRIMARY KEY CLUSTERED (SUBJECT_ID)-- nvals=46520
  )
;




DROP TABLE IF EXISTS PRESCRIPTIONS;
CREATE TABLE PRESCRIPTIONS (	-- rows=4156848
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   ICUSTAY_ID INT ,
   STARTDATE DATETIME,
   ENDDATE DATETIME,
   DRUG_TYPE VARCHAR(255) NOT NULL,	-- max=8
   DRUG VARCHAR(255),	-- max=58
   DRUG_NAME_POE VARCHAR(255),	-- max=58
   DRUG_NAME_GENERIC VARCHAR(255),	-- max=49
   FORMULARY_DRUG_CD VARCHAR(255),	-- max=17
   GSN VARCHAR(200),	-- max=125
   NDC VARCHAR(255),	-- max=11
   PROD_STRENGTH VARCHAR(255),	-- max=60
   DOSE_VAL_RX VARCHAR(255),	-- max=26
   DOSE_UNIT_RX VARCHAR(255),	-- max=32
   FORM_VAL_DISP VARCHAR(255),	-- max=47
   FORM_UNIT_DISP VARCHAR(255),	-- max=13
   ROUTE VARCHAR(255),	-- max=28
   CONSTRAINT PK_PRESCRIPTIONS PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=4156848
  )
;




DROP TABLE IF EXISTS PROCEDUREEVENTS_MV;
CREATE TABLE PROCEDUREEVENTS_MV (	-- rows=258066
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   ICUSTAY_ID INT ,
   STARTTIME DATETIME NOT NULL,
   ENDTIME DATETIME NOT NULL,
   ITEMID INT  NOT NULL,
   VALUE FLOAT NOT NULL,
   VALUEUOM VARCHAR(255) NOT NULL,	-- max=4
   LOCATION VARCHAR(255),	-- max=24
   LOCATIONCATEGORY VARCHAR(255),	-- max=19
   STORETIME DATETIME NOT NULL,
   CGID SMALLINT  NOT NULL,
   ORDERID INT  NOT NULL,
   LINKORDERID INT  NOT NULL,
   ORDERCATEGORYNAME VARCHAR(255) NOT NULL,	-- max=21
   SECONDARYORDERCATEGORYNAME VARCHAR(255),	-- max=0
   ORDERCATEGORYDESCRIPTION VARCHAR(255) NOT NULL,	-- max=12
   ISOPENBAG TINYINT  NOT NULL,
   CONTINUEINNEXTDEPT TINYINT  NOT NULL,
   CANCELREASON TINYINT  NOT NULL,
   STATUSDESCRIPTION VARCHAR(255) NOT NULL,	-- max=15
   COMMENTS_EDITEDBY VARCHAR(255),	-- max=7
   COMMENTS_CANCELEDBY VARCHAR(255),	-- max=17
   COMMENTS_DATE DATETIME,
   CONSTRAINT PK_PROCEDUREEVENTS_MV PRIMARY KEY CLUSTERED (ORDERID)-- nvals=258066
  )
;




DROP TABLE IF EXISTS PROCEDURES_ICD;
CREATE TABLE PROCEDURES_ICD (	-- rows=240095
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   SEQ_NUM TINYINT  NOT NULL,
   ICD9_CODE VARCHAR(255) NOT NULL,	-- max=4
   CONSTRAINT PK_PROCEDURES_ICD PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=240095
  )
;




DROP TABLE IF EXISTS SERVICES;
CREATE TABLE SERVICES (	-- rows=73343
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   TRANSFERTIME DATETIME NOT NULL,
   PREV_SERVICE VARCHAR(255),	-- max=5
   CURR_SERVICE VARCHAR(255) NOT NULL,	-- max=5
   CONSTRAINT PK_SERVICES PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=73343
  )
;




DROP TABLE IF EXISTS TRANSFERS;
CREATE TABLE TRANSFERS (	-- rows=261897
   ROW_ID INT  NOT NULL,
   SUBJECT_ID INT  NOT NULL,
   HADM_ID INT  NOT NULL,
   ICUSTAY_ID INT ,
   DBSOURCE VARCHAR(255),	-- max=10
   EVENTTYPE VARCHAR(255),	-- max=9
   PREV_CAREUNIT VARCHAR(255),	-- max=5
   CURR_CAREUNIT VARCHAR(255),	-- max=5
   PREV_WARDID TINYINT ,
   CURR_WARDID TINYINT ,
   INTIME DATETIME,
   OUTTIME DATETIME,
   LOS FLOAT,
   CONSTRAINT PK_TRANSFERS PRIMARY KEY CLUSTERED (ROW_ID)-- nvals=261897
  )
;


